@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use JSON::Validator::OpenAPI;
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 my $EXCEPTION = {errors => [{message => 'Internal server error.', path => '/'}], status => 500};
 my $NOT_IMPLEMENTED = {errors => [{message => 'Not implemented.', path => '/'}], status => 501};
@@ -53,7 +53,7 @@ sub _add_routes {
         $route->add_child($endpoint);
       }
       if (!$endpoint) {
-        $endpoint = $route->any(_route_path($path, $op_spec));
+        $endpoint = $route->$http_method(_route_path($path, $op_spec));
         $endpoint->name($name) if $name;
       }
 
